@@ -12,7 +12,7 @@ use File::Basename;
 use Test::Builder;
 use File::Find;
 
-our $VERSION = '1.27';
+our $VERSION = '1.31';
 our $VERBOSE = 1;
 
 my $test      = Test::Builder->new();
@@ -59,7 +59,7 @@ sub ok_manifest{
     }
     
     my $bool = 1;
-    my $home = Cwd::realpath( dirname $tmp_path );
+    my $home = Cwd::realpath( $tmp_path );
     my $manifest;
 
     my $counter = 0;
@@ -79,8 +79,10 @@ sub ok_manifest{
     }
     
     my $skip;
-    eval { $skip     = Cwd::realpath( $home . '/MANIFEST.SKIP' ); 1; };
-    
+    my $skip_path = File::Spec->catfile( $home, 'MANIFEST.SKIP' );
+    eval { $skip = Cwd::realpath( $skip_path ) if -f $skip_path; 1; };
+
+    my @dup_files     = ();
     my @missing_files = ();
     my @files_plus    = ();
     my $arref         = ['/blib' , '/_build'];
@@ -114,7 +116,7 @@ sub ok_manifest{
         
         my $files_in_skip = _read_skip( $skip, \$msg, \$bool );
         last unless $files_in_skip;
-            
+
         my @files = _read_file( $fh );
         close $fh;
     
@@ -169,6 +171,10 @@ sub ok_manifest{
         delete $files_hash{$_} for keys %excluded;
         @files_plus = sort keys %files_hash;
         $bool = 0 if scalar @files_plus > 0;
+
+        my %seen_files = ();
+        @dup_files = map { 1==$seen_files{$_}++ ? $_ : () } @files;
+        $bool = 0 if scalar @dup_files > 0;
         
         } # close extra block
     }
@@ -177,21 +183,28 @@ sub ok_manifest{
                join(', ',@missing_files);
     my $plus = 'The following files are not part of distro but named in the MANIFEST file: '.
                join(', ',@files_plus);
+    my $dup  = 'The following files appeared more than once in the MANIFEST file: '.
+               join(', ',@dup_files);
     
     $test->is_num($bool,$test_bool,$msg);
     $test->diag($diag) if scalar @missing_files >= 1 and $test_bool == 1 and $VERBOSE;
     $test->diag($plus) if scalar @files_plus    >= 1 and $test_bool == 1 and $VERBOSE;
+    $test->diag($dup)  if scalar @dup_files     >= 1 and $test_bool == 1 and $VERBOSE;
 }
 
 sub _read_file {
     my ($fh) = @_;
     
     my @files;
+    my $selftest = 0;
+
     while( my $fh_line = <$fh> ){
         chomp $fh_line;
         
+        $selftest++ if $fh_line =~ m{# MANIFEST for Test-CheckManifest};
+
         next if $fh_line =~ m{ \A \s* \# }x;
-        next if $fh_line =~ m{# selftest};
+        next if $selftest && $fh_line =~ m{# selftest};
         
         my ($file);
         
@@ -203,7 +216,7 @@ sub _read_file {
         }
 
         next unless $file;
-        
+
         push @files, $file;
     }
     
@@ -219,8 +232,8 @@ sub _not_ok_manifest{
 sub _is_excluded{
     my ($file,$dirref,$filter,$bool,$files_in_skip,$home) = @_;
     my @excluded_files = qw(
-        pm_to_blib Makefile META.yml Build pod2htmd.tmp LICENSE Makefile.PL
-        pod2htmi.tmp Build.bat .cvsignore MYMETA.json MYMETA.yml License Readme
+        pm_to_blib Makefile META.yml Build pod2htmd.tmp 
+        pod2htmi.tmp Build.bat .cvsignore MYMETA.json MYMETA.yml
     );
 
     if ( $files_in_skip and 'ARRAY' eq ref $files_in_skip ) {
@@ -271,13 +284,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::CheckManifest - Check if your Manifest matches your distro
 
 =head1 VERSION
 
-version 1.27
+version 1.31
 
 =head1 SYNOPSIS
 
@@ -351,6 +366,10 @@ These files not:
 
 =back
 
+By default, C<ok_manifest> will look for the file C<MANIFEST> in the current working directory (which is how tests are traditionally run). If you wish to specify a different directory, you may pass the C<file> or C<dir> parameters, for example:
+
+  ok_manifest({dir => '/path/to/my/dist/'});
+
 =head1 EXCLUDING FILES
 
 Beside C<filter> and C<exclude> there is another way to exclude files:
@@ -370,7 +389,7 @@ Renee Baecker <reneeb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Renee Baecker.
+This software is Copyright (c) 2015 by Renee Baecker.
 
 This is free software, licensed under:
 
